check_data: Validate CIC Input Data

View source: R/diagnostics.R

check_dataR Documentation

Validate CIC Input Data

Description

Checks for common data issues and issues informative warnings. Called internally by cic when input is potentially problematic. Also available for manual use.

Usage

check_data(y_00, y_01, y_10, y_11)

Arguments

y_00, y_01, y_10, y_11

Numeric vectors of outcomes.

Value

Invisible TRUE. Produces warnings for potential issues.


sccic documentation built on April 10, 2026, 5:07 p.m.