integral_quantile: Integral of empirical quantile function

View source: R/ecdf_utils.R

integral_quantileR Documentation

Integral of empirical quantile function

Description

Computes \int_a^b Q(u) \, du where Q is the empirical quantile function of ec, i.e., Q(u) = \inf\{y : F(y) \ge u\}. Used by the discrete CIC estimator to average the counterfactual over a quantile band.

Usage

integral_quantile(ec, a, b)

Arguments

ec

An ecdf object from make_ecdf.

a

Lower integration limit in [0, 1].

b

Upper integration limit in [0, 1].

Value

Numeric scalar equal to the integral.


sccic documentation built on April 10, 2026, 5:07 p.m.