quantile_te: Compute Quantile Treatment Effects

View source: R/diagnostics.R

quantile_teR Documentation

Compute Quantile Treatment Effects

Description

Estimates quantile treatment effects from a CIC fit by comparing quantiles of the actual post-treatment treated distribution with quantiles of the counterfactual distribution.

Usage

quantile_te(x, probs = seq(0.05, 0.95, 0.05))

Arguments

x

An object of class "cic" or "sc_cic".

probs

Numeric vector of quantiles at which to compute effects. Default is seq(0.05, 0.95, 0.05).

Details

The quantile treatment effect at quantile q is:

\hat{\tau}_q = \hat{F}^{-1}_{Y^I,11}(q) - \hat{F}^{-1}_{Y^N,11}(q)

where \hat{F}^{-1}_{Y^N,11} is the CIC counterfactual distribution.

Value

A data frame with columns quantile, actual, counterfactual, and qte (quantile treatment effect).


sccic documentation built on April 10, 2026, 5:07 p.m.