| plot.sc_cic | R Documentation |
Plots the treated unit against the synthetic control over time, with a vertical line at the treatment period.
## S3 method for class 'sc_cic'
plot(x, ...)
x |
An object of class |
... |
Additional arguments passed to |
The plot shows the treated unit (solid line) and synthetic control (dashed line) over all time periods, with a vertical dashed line marking the start of treatment. Good pre-treatment fit is a necessary (but not sufficient) condition for valid SC-CIC inference.
Invisible. Called for its side effect of producing a plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.