| quantile_te | R Documentation |
Estimates quantile treatment effects from a CIC fit by comparing quantiles of the actual post-treatment treated distribution with quantiles of the counterfactual distribution.
quantile_te(x, probs = seq(0.05, 0.95, 0.05))
x |
An object of class |
probs |
Numeric vector of quantiles at which to compute effects.
Default is |
The quantile treatment effect at quantile q is:
\hat{\tau}_q = \hat{F}^{-1}_{Y^I,11}(q) - \hat{F}^{-1}_{Y^N,11}(q)
where \hat{F}^{-1}_{Y^N,11} is the CIC counterfactual distribution.
A data frame with columns quantile, actual,
counterfactual, and qte (quantile treatment effect).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.