| sccic-package | R Documentation |
Implements the Changes-in-Changes (CIC) estimator of Athey and Imbens (2006) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/j.1468-0262.2006.00668.x")} combined with synthetic control methods. Provides both the continuous CIC estimator (Theorem 3.1) and the discrete CIC estimator (Theorem 4.1) for integer-valued outcomes, with analytic and bootstrap inference. Also provides nonparametric estimation of the entire counterfactual distribution of outcomes for a treated group, allowing evaluation of average, quantile, and distributional treatment effects. Synthetic control weights are constructed via elastic net regularization to handle settings with many potential control units.
Implements the Changes-in-Changes (CIC) estimator of Athey and Imbens (2006) combined with synthetic control methods for causal inference in difference-in-differences settings.
cicStandard CIC estimator for two groups and two periods, with analytic and bootstrap inference.
sc_cicCombined synthetic control + CIC estimator for settings with a single treated unit and multiple donor units.
Maintainer: Neil Hwang neil.hwang@bcc.cuny.edu
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.